%MINRESPolyMain
%
%Version 10.09.04 by Bernd Fischer


%Dimension of the system
N=100; 

%Eigenvalue bounds
a=-6; b=-2; c=1; d=3;

%initial guess and solution
x_star=ones(N,1);
rand('state',0); x0=2*rand(N,1)-1;

%Stopping criteria
n_max=2*N;
tol=1e-15;

%Maximal polynomial degree and number of sample points
m=25;
dis=100;





matrix=menu('Choose matrix','Equidistant (two intervals)',...
            'Helmholtz matrix','VanDerVorst (N=100)');

if matrix == 1
%Equidistant2: Equidistant in [a,b] u [c,d]
  i1 = floor( N * (b - a) / (b - a + d - c) );
  A = [ linspace( a, b, i1 ), linspace( c, d, N-i1 ) ]';
  colour='g';
end

if matrix == 2
%Helmholtz: shifted Laplace matrix in [a,b]
  Shift=0.5;
  n=sqrt(N); n=floor(n);
  h = 1 / (n + 1);
  lambda = zeros(n^2, 1);

  j = 0;
    for k = 1:n,
        for l = 1:n,
            j           = j + 1;
            lambda(j)   = 4 + 2 * cos(k*pi*h) + 2 * cos(l*pi*h);
        end;
    end
  A=lambda;
  A=A-Shift;
  colour='r';
end

if matrix == 3
%VanDerVorst: shifted van der Vorst Matrix;
  Shift=0;
  %Shift=-.97778;
  A=[-9:2:189]';
  A=A-Shift; 
  colour='b';
end

matvec='mvdiag';
%Righthandside
rhs=feval( matvec, A, x_star );

%CR iteration
[xCR, plotresCR, ploterrCR, alpha, beta, gamma] = ...
        cr_poly(A, rhs, x0, n_max, tol, matvec, x_star);
    
%MINRES iteration
[xMR, plotresMR, ploterrMR, xGAL, plotresGAL, ploterrGAL] = ...
        MINRES(A, rhs, x0, n_max, tol, matvec, x_star);

%CG iteration
[xCG, plotresCG, ploterrCG] = ...
         CG(A, rhs, x0, n_max, tol, matvec, x_star)


figure(1)
it=min([length(plotresCR)]);
plot(1:it,plotresCR(1:it),'g','linewidth',2);
hold on
it=min([length(plotresMR)]);
plot(1:it,plotresMR(1:it),'r','linewidth',2);
it=min([length(plotresCG)]);
plot(1:it,plotresCG(1:it),'b','linewidth',2);
hold off

title('Convergence history for CR (g), CG (b) and MINRES(r)')
xlabel('Iterations')
ylabel('relative residual norm')


polynom=menu('Iteration polynomial ?', 'Yes', 'No');

if polynom == 1 

%Compute polynomial
t=linspace(min(A)-1,max(A)+1,dis);
pm=zeros(m,dis);
for j=1:m
   pm(j,:)=orthopol(t,j,gamma,alpha,beta,1);
end


figure(2)
for j=2:m
   plot(0,1,'o')
   hold on
   plot([min(A)-1,max(A)+1],[0,0])
   plot([0,0],[-1.5,1.5])
   for k=1:N
      plot([A(k),A(k)],[-.1,.1],'g','linewidth',1.5)
   end
   plot(t,pm(j-1,:),'k','linewidth',2)
   plot(t,pm(j,:),'r','linewidth',2)
   drawnow, axis([min(A)-1,max(A)+1,-1.25,1.25])
   title('Eigenvalues and CR - polynomial')
   xlabel(['Polynomial degree: ', int2str(j-1),'/ ', int2str(j)])
   hold off
   choice=menu('Higher degree','    Yes   ','    No    '),
   if choice ~= 1, break, end
   clf, 
end
end

 

return