function [eigFsup,VFsup,lambda,mu,gamma]=...
          eigFsup(h,nx,epsilon,delta,beta_x,beta_y)
%
% Version: 31.08.98 by Bernd Fischer
%
% computes the eigenvalues eigFsup, the eigenvectors VFsup
% of the matrix Fsup 
% and the eigenvalues lambda,mu,gamma of the corresponding submatrices 
% based upon Alisons analysis
%
% 

%%matrix entries 
   ca=8/3*epsilon+delta*h*4/3*(beta_x*beta_x+beta_y*beta_y);
   cb=-1/3*epsilon+h/3*beta_x+delta*h/3*(-2*beta_x*beta_x+beta_y*beta_y); 
   cc=-1/3*epsilon-h/3*beta_x+delta*h/3*(-2*beta_x*beta_x+beta_y*beta_y); 
   cd=-1/3*epsilon+h/3*beta_y+delta*h/3*(beta_x*beta_x-2*beta_y*beta_y); 
   cg=-1/3*epsilon-h/3*beta_y+delta*h/3*(beta_x*beta_x-2*beta_y*beta_y); 
   ce=-1/3*epsilon+h/12*(beta_x+beta_y)-...
       delta*h*(1/6*(beta_x*beta_x+beta_y*beta_y)+1/2*beta_x*beta_y); 
   cf=-1/3*epsilon+h/12*(-beta_x+beta_y)-...
       delta*h*(1/6*(beta_x*beta_x+beta_y*beta_y)-1/2*beta_x*beta_y); 
   ch=-1/3*epsilon+h/12*(beta_x-beta_y)-...
       delta*h*(1/6*(beta_x*beta_x+beta_y*beta_y)-1/2*beta_x*beta_y); 
   ci=-1/3*epsilon-h/12*(beta_x+beta_y)-...
       delta*h*(1/6*(beta_x*beta_x+beta_y*beta_y)+1/2*beta_x*beta_y); 
   
%%compute eigenvalues of Fsup by Alisons formulae
   j=1:nx; n=nx+1;
   cos_j=cos(pi*j/n);
   gamma =cg+2.*sign(ch)*sqrt(ci*ch)*cos_j ;  %eigenvalues of left block
   lambda=ca+2.*sign(cb)*sqrt(cc*cb)*cos_j ;  %eigenvalues of middle block
   mu    =cd+2.*sign(ce)*sqrt(cf*ce)*cos_j ;  %eigenvalues of right block
   
   mat_eigFsup=(2*sign(mu).*sqrt(gamma.*mu))'*cos_j;  
   for k=1:nx mat_eigFsup(1:nx,k)=mat_eigFsup(1:nx,k)+lambda'; end 
   
   eigFsup=reshape((mat_eigFsup'),nx*nx,1);   %eigenvalues of Fsup
 
%%compute eigenvectors of Fsup by Alisons formulae 

%%eigenvector matrix for each individual block
   U=zeros(nx,nx);
   for k=1:nx
      U(:,k)=sin(j'*k*pi/n);
   end

%%eigenvector matrix for the block tridiagonal matrix
   VFsup=zeros(nx^2,nx^2);
   p=sqrt(gamma./mu);
   C=0;
   for j=1:nx
      for k=1:nx
         C=C+1;
         for l=1:nx
            VFsup((l-1)*nx+1:l*nx,C)= p(j)^l*sin(l*k*pi/n)*U(:,j);
	     end
      end
   end
 
%%column norm-equilibrated to 1   
   for j=1:nx^2
      VFsup(:,j)=VFsup(:,j)/norm(VFsup(:,j));
   end
   
   
return
